#setwd("D:/Dom Documents/PhD (ANU) (09_08_2013)/ANU - Jennions/Post-Doc/Contracts/SHOU 2014/Flounder project/MS/Data and analysis/Archived data")
#setwd("C:/Dom Documents/PhD (ANU) (09_08_2013)/ANU - Jennions/Post-Doc/Contracts/SHOU 2014/Flounder project/MS/Data and analysis/Archived data")
setwd("C:/Users/Acer/Dropbox/Flounder project/MS/Data and analysis/Archived data")

require(ade4)
require(nlme)
require(car)
require(ggplot2)
require(MuMIn)
require(effects)
require(vegan)
require(cluster)
require(gclus)

#######
# Datasets
#######

flou <-read.csv("Rupia_et_al_behav_data.csv", h=T)
names(flou)
head(flou)    
summary(flou)
dim(flou)

rupia <-read.csv("Rupia_et_al_behav_metabolic_data.csv", h=T)
rupia$group <- rupia$salinity:rupia$behavType
names(rupia)
head(rupia)
summary(rupia)
dim(rupia)


#------------------------------------- Behavioural data -------------------------------------

## 25ppt
flou25 <- flou[flou$salinity=="25ppt",]
flou25$salinity <- factor(flou25$salinity)[,drop=T]
summary(flou25)
names(flou25)
head(flou25)

## 3ppt
flou3 <- flou[flou$salinity=="3ppt",]
flou3$salinity <- factor(flou3$salinity)[,drop=T]
summary(flou3)
names(flou3)
head(flou3)

##################################
# PCA (Hill&Smith)
##################################

## 25ppt

head(flou25)
summary(flou)
flou25$captureSim <- as.factor(flou25$captureSim)
is.factor(flou25$captureSim)
dudi25<-dudi.hillsmith(flou25[,3:8], scannf = F, nf = 2)
scatter.dudi(dudi25) #plot
dudi25$eig[1]/sum(dudi25$eig) #percentage of variance explained by Pc1 (85.0)
dudi25$c1 #loadings
dudi25$co #correlations between variables and PCs
dudi25$li #get Pcs

## 3ppt

head(flou3)
summary(flou3)
flou3$captureSim <- as.factor(flou3$captureSim)
is.factor(flou3$captureSim)
dudi3<-dudi.hillsmith(flou3[,3:8], scannf = F, nf = 2)
scatter.dudi(dudi3) #plot
dudi3$eig[1]/sum(dudi3$eig) #percentage of variance explained by Pc1 (82.2)
dudi3$c1 #loadings
dudi3$co #correlations between variables and PCs
dudi3$li #get Pcs


##################################
# repeatability of behavioural scores
##################################

Behav25ppt <- rupia$behAxis1[rupia$salinity=="25ppt"]
Behav3ppt <- rupia$behAxis1[rupia$salinity=="3ppt"]

plot(Behav25ppt, Behav3ppt)
cor.test(Behav25ppt, Behav3ppt, method = "pearson")
lm1 <- lm(Behav25ppt ~ Behav3ppt)
summary(lm1)

# Figure
qplot(Behav25ppt, Behav3ppt, colour = I("blue"), size = I(4)) + theme_bw() + theme(legend.position="none") 


##################################
# Clustering analysis (Behavioural score)
##################################

matrixhillsmith <-  cbind.data.frame(rupia$behAxis1, rupia$behAxis1)
row.names(matrixhillsmith) <- rupia$fishID:rupia$salinity
mhs.ch <- vegdist(matrixhillsmith , "euc")
mhs.ch.ward <- hclust(mhs.ch, method="ward")

# plot 1

plot(mhs.ch.ward, hang = -1); rect.hclust(mhs.ch.ward, k=2, border="red")

# plot 2

source("http://addictedtor.free.fr/packages/A2R/lastVersion/R/code.R")
# colored dendrogram
op = par(bg = "#EFEFEF")
A2Rplot(mhs.ch.ward, k = 2, boxes = FALSE, col.up = "black", col.down = c("#FF6B6B","#4ECDC4"))


# Optimal number of clusters according to silhouette widths (Rousseeuw quality index)

asw <- numeric(nrow(matrixhillsmith))
for (k in 2:(nrow(matrixhillsmith)-1)) {
	sil <- silhouette(cutree(mhs.ch.ward, k=k), mhs.ch)
	asw[k] <- summary(sil)$avg.width
	}
k.best <- which.max(asw)
# The plot is produced by function plot.silhouette {cluster}
windows(title="Silhouettes - Ward - k = 2 to n-1")
plot(1:nrow(matrixhillsmith), asw, type="h", 
  main="Silhouette-optimal number of clusters, Ward", 
	xlab="k (number of groups)", ylab="Average silhouette width")
axis(1, k.best, paste("optimum",k.best,sep="\n"), col="red", font=2,
  col.axis="red")
points(k.best, max(asw), pch=16, col="red", cex=1.5)
cat("", "Silhouette-optimal number of clusters k =", k.best, "\n", 
	"with an average silhouette width of", max(asw), "\n")

# Silhouette plot of the final partition

k <- 2 #Number of groups found above
cutg <- cutree(mhs.ch.ward, k=k)
sil <- silhouette(cutg, mhs.ch)
silo <- sortSilhouette(sil)
rownames(silo) <- row.names(matrixhillsmith)[attr(silo,"iOrd")]
windows(title="Silhouette plot - Ward - K=2")
plot(silo, main="Silhouette plot - Chord - Ward", 
	cex.names=0.8, col=cutg+1, nmax.lab=100)






#------------------------------------- Metabolic data -------------------------------------

rupia25ppt <- data.frame(rupia[rupia$salinity=="25ppt", ])
rupia25ppt <- droplevels(rupia25ppt)
rupia3ppt <- rupia[rupia$salinity=="3ppt", ]
rupia3ppt <- droplevels(rupia3ppt)

smr25ppt <- rupia$SMR[rupia$salinity=="25ppt"]
smr3ppt <- rupia$SMR[rupia$salinity=="3ppt"]
mmr25ppt <- rupia$MMR[rupia$salinity=="25ppt"]
mmr3ppt <- rupia$MMR[rupia$salinity=="3ppt"]

##################################
# repeatability of SMR and MMR across salinities
##################################

### SMR

plot(smr3ppt, smr25ppt)
cor.test(smr3ppt, smr25ppt, method = "pearson")
lm2 <- lm(smr25ppt ~ smr3ppt)
summary(lm2)
qplot(smr25ppt, smr3ppt, colour = I("blue"), size = I(4)) + theme_bw() + theme(legend.position="none") 

### MMR

plot(mmr3ppt, mmr25ppt)
cor.test(mmr3ppt, mmr25ppt, method = "pearson")
lm3 <- lm(mmr25ppt ~ mmr3ppt)
summary(lm3)
qplot(mmr25ppt, mmr3ppt, colour = I("blue"), size = I(4)) + theme_bw() + theme(legend.position="none") 


##################################
# SMR vs MMR (at both salinities, controlling for mass)
##################################

######
# 25 ppt
######

# resisuals of SMR ~ mass

plot(rupia25ppt$mass, rupia25ppt$SMR)
masscorSMR25x <- lm(SMR ~ mass * behavType, data = rupia25ppt)
plot(masscorSMR25x) # heteroscedastic
masscorSMR25 <- gls(SMR ~ mass * behavType, weights=varIdent(form=~1|behavType), data = rupia25ppt)
plot(masscorSMR25) # gls corrects for heteroscedasticity
qqPlot(resid(masscorSMR25)) #normal
summary(masscorSMR25)
anova(masscorSMR25)
SMRres25 <- resid(masscorSMR25)

qplot(rupia25ppt$mass, rupia25ppt$SMR, colour = rupia25ppt$behavType, size = I(4)) + theme_bw() + theme(legend.position="none") + 
	geom_smooth(method="lm", size=1)

# resisuals of MMR ~ mass

plot(rupia25ppt$mass, rupia25ppt$MMR)
masscorMMR25 <- gls(MMR ~ mass * behavType, weights=varIdent(form=~1|behavType), data = rupia25ppt)
plot(masscorMMR25) # gls corrects for heteroscedasticity
qqPlot(resid(masscorMMR25)) #normal
summary(masscorMMR25)
anova(masscorMMR25)
MMRres25 <- resid(masscorMMR25)

qplot(rupia25ppt$mass, rupia25ppt$MMR, colour = rupia25ppt$behavType, size = I(4)) + theme_bw() + theme(legend.position="none") + 
	geom_smooth(method="lm", size=1)

# MMR vs SMR

plot(SMRres25, MMRres25)
cor.test(SMRres25, MMRres25, method = "pearson")
qplot(SMRres25, MMRres25, colour = I("blue"), size = I(4)) + theme_bw() + theme(legend.position="none")

######
# 3 ppt
######

# resisuals of SMR ~ mass

plot(rupia3ppt$mass, rupia3ppt$SMR)
masscorSMR3x <- lm(SMR ~ mass * behavType, data = rupia3ppt)
plot(masscorSMR3x) # heteroscedastic
masscorSMR3 <- gls(SMR ~ mass * behavType, weights=varIdent(form=~1|behavType), data = rupia3ppt)
plot(masscorSMR3) # gls corrects for heteroscedasticity
qqPlot(resid(masscorSMR3)) #normal
summary(masscorSMR3)
anova(masscorSMR3)
SMRres3 <- resid(masscorSMR3)
qplot(rupia3ppt$mass, rupia3ppt$SMR, colour = rupia3ppt$behavType, size = I(4)) + theme_bw() + theme(legend.position="none") + 
	geom_smooth(method="lm", size=1)

# resisuals of MMR ~ mass

plot(rupia3ppt$mass, rupia3ppt$MMR)
masscorMMR3x <- lm(MMR ~ mass, data = rupia3ppt) 
plot(masscorMMR3x)
masscorMMR3 <- gls(MMR ~ mass * behavType, weights=varIdent(form=~1|behavType), data = rupia3ppt)
plot(masscorMMR3) # gls corrects for heteroscedasticity
qqPlot(resid(masscorMMR3)) #normal
summary(masscorMMR3)
anova(masscorMMR3)
MMRres3 <- resid(masscorMMR3)
qplot(rupia3ppt$mass, rupia3ppt$MMR, colour = rupia3ppt$behavType, size = I(4)) + theme_bw() + theme(legend.position="none") + 
	geom_smooth(method="lm", size=1)

# MMR vs SMR

plot(SMRres3, MMRres3)
cor.test(SMRres3, MMRres3, method = "pearson")
qplot(SMRres3, MMRres3, colour = I("blue"), size = I(4)) + theme_bw() + theme(legend.position="none")


##################################
# SMR ~ behavioural type
##################################

# Figure (behAxis1 ~ SMR)
qplot(SMR, behAxis1, data = rupia, colour = I("blue"), size = I(4), shape = salinity) + theme_bw() + theme(legend.position="none") +
	geom_smooth(aes(group=group), method="lm", size=1)

# LMM
smr1 <- lme(SMR ~ salOrder + mass + behavType * salinity,random=~1|fishID, data=rupia)
smr2 <- lme(SMR ~ salOrder + mass + behavType * salinity, weights=varIdent(form=~1|behavType),
	random=~1|fishID, data=rupia)
anova(smr1, smr2)
plot(smr1)
qqPlot(resid(smr1))
qqnorm(smr1, ~ ranef(., level=1))
summary(smr1)
anova(smr1)
r.squaredGLMM(smr1)

##################################
# MMR ~ behavioural type
##################################

# Figure
qplot(MMR, behAxis1, data = rupia, colour = I("blue"), size = I(4), shape = salinity) + theme_bw() + theme(legend.position="none") +
	geom_smooth(aes(group=group), method="lm", size=1)

# LMM
mmr1 <- lme(MMR ~ salOrder + mass + behavType * salinity, random=~1|fishID, data=rupia)
mmr2 <- lme(MMR ~ salOrder + mass + behavType * salinity, weights=varIdent(form=~1|behavType),
	random=~1|fishID, data=rupia)
anova(mmr1, mmr2)
plot(mmr1)
qqPlot(resid(mmr1))
qqnorm(mmr1, ~ ranef(., level=1))
summary(mmr1)
anova(mmr1)
r.squaredGLMM(mmr1)

##################################
# AAS ~ behavioural type
##################################

# Figure
qplot(AAS, behAxis1, data = rupia, colour = I("blue"), size = I(4), shape = salinity) + theme_bw() + theme(legend.position="none") +
	geom_smooth(aes(group=group), method="lm", size=1)

# LMM
aas1 <- lme(AAS ~ salOrder + mass + behavType * salinity, random=~1|fishID, data=rupia)
aas2 <- lme(AAS ~ salOrder + mass + behavType * salinity, weights=varIdent(form=~1|behavType),
	random=~1|fishID, data=rupia)
anova(aas1, aas2)
plot(aas1)
qqPlot(resid(aas1))
qqnorm(aas1, ~ ranef(., level=1))
summary(aas1)
anova(aas1)
r.squaredGLMM(aas1)







#------------------------------------- Defence response -------------------------------------

# Data

startlemeans <- read.csv("Rupia_et_al_Fig4A_data.csv", header=T)
head(startlemeans)
summary(startlemeans)

startle <- read.csv("Rupia_et_al_Fig4B_data.csv", header=T)
head(startle)
summary(startle)
startle$groups <- startle$salinity:startle$behavType

diff<-read.csv("Rupia_et_al_defense_resp_data.csv", header=T)
head(diff)
summary(diff)

# Figure of raw data - mean and SE (Fig. 4A in ms)

limits <- aes(ymax = MO2 + SE, ymin= MO2 - SE)
qplot(time, MO2, data = startlemeans, colour = salinity, size = I(4), shape = behavType) +
	geom_errorbar(limits, width=0.2) + theme_bw()+ theme(legend.position="none") +
	geom_line(aes(group=treat))

# Figure of model predictions (Fig. 4B in ms)

Mstartle<-lme(log(MO2) ~ scale(mass) + time * behavType * salinity, random=~1|fishID, data = startle)
plot(Mstartle)
qqPlot(resid(Mstartle))
summary(Mstartle)
anova(Mstartle)
plot(effect("time:behavType", Mstartle, confidence.level = 0.68), ylim=c(1.5,3.5)) # 68% CI is equal to one SE

######
# LMM bold fish
#####

tBold<-diff[diff$behavType=="Bold", ]
lmmbold <- lme(log(MO2) ~ mass + time, random=~1|fishID, data = tBold)
plot(lmmbold)
qqPlot(resid(lmmbold))
summary(lmmbold)
anova(lmmbold)
r.squaredGLMM(lmmbold)
plot(effect("time", lmmbold))

######
# LMM shy fish
#####

tShy<-diff[diff$behavType=="Shy", ]
lmmshy <- lme(log(MO2) ~ mass + time, random=~1|fishID, data = tShy)
plot(lmmshy)
qqPlot(resid(lmmshy))
summary(lmmshy)
anova(lmmshy)
r.squaredGLMM(lmmshy)
plot(effect("time", lmmshy))


